@@ -38,6 +38,7 @@ AppDragWidget::AppDragWidget(QWidget *parent)
     , m_popupWindow(new DockPopupWindow(nullptr))
     , m_distanceMultiple(Utils::SettingValue("com.deepin.dde.dock.distancemultiple", "/com/deepin/dde/dock/distancemultiple/", "distance-multiple", 1.5).toDouble())
     , m_item(nullptr)
+    , m_cursorPosition(-1, -1)
 {
     m_removeTips->setText(tr("Remove"));
     m_removeTips->setObjectName("AppRemoveTips");
@@ -60,6 +61,8 @@ AppDragWidget::AppDragWidget(QWidget *parent)
     if (Utils::IS_WAYLAND_DISPLAY) {
         setWindowFlags(Qt::WindowStaysOnTopHint | Qt::X11BypassWindowManagerHint | Qt::Window);
         setAttribute(Qt::WA_NativeWindow);
+    } else {
+        setAcceptDrops(true);
     }
     viewport()->setAutoFillBackground(false);
     setFrameShape(QFrame::NoFrame);
@@ -67,8 +70,6 @@ AppDragWidget::AppDragWidget(QWidget *parent)
     setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
     setMouseTracking(true);
 
-    setAcceptDrops(true);
-
     initAnimations();
 
     m_followMouseTimer->setInterval(16);
@@ -89,16 +90,23 @@ void AppDragWidget::mouseMoveEvent(QMouseEvent *event)
 
 void AppDragWidget::dragEnterEvent(QDragEnterEvent *event)
 {
-    event->accept();
-    m_bDragDrop = true;
+    if (Utils::IS_WAYLAND_DISPLAY) {
+        QGraphicsView::dragEnterEvent(event);
+    } else {
+        event->accept();
+        m_bDragDrop = true;
+    }
 }
 
 void AppDragWidget::dragMoveEvent(QDragMoveEvent *event)
 {
-    Q_UNUSED(event);
-    showRemoveTips();
-    if (isRemoveItem() && m_bDragDrop) {
-        emit requestRemoveItem();
+    if (Utils::IS_WAYLAND_DISPLAY) {
+        QGraphicsView::dragMoveEvent(event);
+    } else {
+        showRemoveTips();
+        if (isRemoveItem() && m_bDragDrop) {
+            emit requestRemoveItem();
+        }
     }
 }
 
@@ -139,7 +147,7 @@ const QPoint AppDragWidget::popupMarkPoint(Dock::Position pos)
         break;
     case Bottom:
         if (!DWindowManagerHelper::instance()->hasComposite()) {
-            p += QPoint(0 , -r.height() / 2);
+            p += QPoint(size().width() / 2 , -r.height() / 2);
         } else {
             p += QPoint(r.width() / 2, 0);
         }
@@ -156,23 +164,27 @@ const QPoint AppDragWidget::popupMarkPoint(Dock::Position pos)
 
 void AppDragWidget::dropEvent(QDropEvent *event)
 {
-    m_followMouseTimer->stop();
-    m_bDragDrop = false;
-
-    if (isRemoveAble(QCursor::pos())) {
-        if (DWindowManagerHelper::instance()->hasComposite()) {
-            showRemoveAnimation();
-        } else {
-            hide();
-        }
-        AppItem *appItem = static_cast<AppItem *>((Utils::IS_WAYLAND_DISPLAY && m_item) ? m_item : event->source());
-        appItem->undock();
-        m_popupWindow->setVisible(false);
+    if (Utils::IS_WAYLAND_DISPLAY) {
+        QGraphicsView::dropEvent(event);
     } else {
-        if (DWindowManagerHelper::instance()->hasComposite()) {
-            showGoBackAnimation();
+        m_followMouseTimer->stop();
+        m_bDragDrop = false;
+
+        if (isRemoveAble(QCursor::pos())) {
+            if (DWindowManagerHelper::instance()->hasComposite()) {
+                showRemoveAnimation();
+            } else {
+                hide();
+            }
+            AppItem *appItem = static_cast<AppItem *>((Utils::IS_WAYLAND_DISPLAY && m_item) ? m_item : event->source());
+            appItem->undock();
+            m_popupWindow->setVisible(false);
         } else {
-            hide();
+            if (DWindowManagerHelper::instance()->hasComposite()) {
+                showGoBackAnimation();
+            } else {
+                hide();
+            }
         }
     }
 }
@@ -371,11 +383,7 @@ bool AppDragWidget::isRemoveItem()
 void AppDragWidget::onFollowMouse()
 {
     QPoint destPos = QCursor::pos();
-    if (DWindowManagerHelper::instance()->hasComposite()) {
-        move(destPos.x() - width() / 2, destPos.y() - height() / 2);
-    } else {
-        move(destPos.x(), destPos.y()); // 窗口特效未开启时会隐藏m_object绘制的图标，移动的图标为QDrag绘制的图标
-    }
+    move(destPos.x() - width() / 2, destPos.y() - height() / 2);
 }
 
 void AppDragWidget::enterEvent(QEvent *event)
@@ -388,6 +396,14 @@ void AppDragWidget::enterEvent(QEvent *event)
     }
 }
 
+bool AppDragWidget::event(QEvent *event)
+{
+    if (Utils::IS_WAYLAND_DISPLAY && event->type() == QEvent::DeferredDelete)
+        requestRemoveSelf(isRemoveAble(m_cursorPosition));
+
+    return QGraphicsView::event(event);
+}
+
 /**显示移除应用提示窗口
  * @brief AppDragWidget::showRemoveTips
  */
@@ -430,4 +446,10 @@ void AppDragWidget::moveEvent(QMoveEvent *event)
 {
     Q_UNUSED(event);
     showRemoveTips();
+    if (Utils::IS_WAYLAND_DISPLAY) {
+        m_cursorPosition = QCursor::pos();
+        if (isRemoveItem()) {
+            emit requestRemoveItem();
+        }
+    }
 }
