@@ -25,12 +25,16 @@
 #include <QWidget>
 #include <QPixmap>
 #include <QSvgRenderer>
+#include <QApplication>
+
+class QCursor;
 
 class ImageUtil
 {
 public:
     static const QPixmap loadSvg(const QString &iconName, const QString &localPath, const int size, const qreal ratio);
-    static const QPixmap loadSvg(const QString &iconName, const QSize size, const qreal ratio);
+    static const QPixmap loadSvg(const QString &iconName, const QSize size, const qreal ratio = qApp->devicePixelRatio());
+    static QCursor* loadQCursorFromX11Cursor(const char* theme, const char* cursorName, int cursorSize);
 };
 
 #endif // IMAGEUTIL_H
