@@ -30,6 +30,13 @@ class PluginLoader : public QThread
 
 public:
     explicit PluginLoader(const QString &pluginDirPath, QObject *parent);
+    static QString libUsedDtkCoreFileName(const QString &fileName);
+    /**
+     * @brief realFileName 获取软连接的真实文件的路径
+     * @param fileName 文件地址
+     * @return
+     */
+    static QString realFileName(QString fileName);
 
 signals:
     void finished() const;
@@ -39,8 +46,6 @@ protected:
     void run();
 
     QString dtkCoreFileName();
-    QString libUsedDtkCoreFileName(const QString &fileName);
-    QString realFileName(QString fileName);                 // 获取软连接的真实文件的路径
 
 private:
     QString m_pluginDirPath;
