@@ -74,7 +74,7 @@ ModuleWidget::ModuleWidget(QWidget *parent)
     , m_pluginModel(new QStandardItemModel(this))
     , m_daemonDockInter(new DBusDock("com.deepin.dde.daemon.Dock", "/com/deepin/dde/daemon/Dock", QDBusConnection::sessionBus(), this))
     , m_dockInter(new DBusInter("com.deepin.dde.Dock", "/com/deepin/dde/Dock", QDBusConnection::sessionBus(), this))
-    , m_dconfigWatcher(new ConfigWatcher("dde.dock.plugin.dconfig", this))
+    , m_dconfigWatcher(new ConfigWatcher("org.deepin.dde.control-center", "org.deepin.dde.dock.plugin", this))
     , m_sliderPressed(false)
 {
     //~ contents_path /personalization/Dock
@@ -132,7 +132,7 @@ void ModuleWidget::initUI()
             m_modeComboxWidget->setCurrentText(g_modeMap.key(mode));
         });
         layout->addWidget(m_modeComboxWidget);
-        m_dconfigWatcher->bind("Control-Center_Dock_Model", m_modeComboxWidget);
+        m_dconfigWatcher->bind("dockModel", m_modeComboxWidget);
     } else {
         m_modeComboxWidget->setVisible(false);
     }
@@ -161,7 +161,7 @@ void ModuleWidget::initUI()
             m_positionComboxWidget->setCurrentText(g_positionMap.key(pos));
         });
         layout->addWidget(m_positionComboxWidget);
-        m_dconfigWatcher->bind("Control-Center_Dock_Location", m_positionComboxWidget);
+        m_dconfigWatcher->bind("dockLocation", m_positionComboxWidget);
     } else {
         m_positionComboxWidget->setVisible(false);
     }
@@ -189,7 +189,7 @@ void ModuleWidget::initUI()
             m_stateComboxWidget->setCurrentText(g_stateMap.key(mode));
         });
         layout->addWidget(m_stateComboxWidget);
-        m_dconfigWatcher->bind("Control-Center_Dock_State", m_stateComboxWidget);
+        m_dconfigWatcher->bind("dockState", m_stateComboxWidget);
     } else {
         m_stateComboxWidget->setVisible(false);
     }
@@ -223,7 +223,7 @@ void ModuleWidget::initUI()
     });
 
     updateSliderValue();
-    m_dconfigWatcher->bind("Control-Center_Dock_Size", m_sizeSlider);
+    m_dconfigWatcher->bind("dockSize", m_sizeSlider);
 
     layout->addWidget(m_sizeSlider);
 
@@ -263,8 +263,8 @@ void ModuleWidget::initUI()
             m_screenSettingComboxWidget->blockSignals(false);
         });
         layout->addWidget(m_screenSettingComboxWidget);
-        m_dconfigWatcher->bind("Control-Center_Dock_Multi-screen", m_screenSettingTitle);
-        m_dconfigWatcher->bind("Control-Center_Dock_Multi-screen", m_screenSettingComboxWidget);
+        m_dconfigWatcher->bind("multiscreen", m_screenSettingTitle);
+        m_dconfigWatcher->bind("multiscreen", m_screenSettingComboxWidget);
     } else {
         m_screenSettingTitle->setVisible(false);
         m_screenSettingComboxWidget->setVisible(false);
@@ -293,7 +293,7 @@ void ModuleWidget::initUI()
         if (plugins.size() != 0) {
             layout->addSpacing(10);
             layout->addWidget(m_pluginAreaTitle);
-            m_dconfigWatcher->bind("Control-Center_Dock_Plugins", m_pluginAreaTitle);
+            m_dconfigWatcher->bind("dockPlugins", m_pluginAreaTitle);
 
             DFontSizeManager::instance()->bind(m_pluginTips, DFontSizeManager::T8);
             m_pluginTips->adjustSize();
@@ -301,7 +301,7 @@ void ModuleWidget::initUI()
             m_pluginTips->setContentsMargins(10, 5, 10, 5);
             m_pluginTips->setAlignment(Qt::AlignLeft);
             layout->addWidget(m_pluginTips);
-            m_dconfigWatcher->bind("Control-Center_Dock_Plugins", m_pluginTips);
+            m_dconfigWatcher->bind("dockPlugins", m_pluginTips);
 
             m_pluginView->setAccessibleName("pluginList");
             m_pluginView->setBackgroundType(DStyledItemDelegate::BackgroundType::ClipCornerBackground);
@@ -325,7 +325,7 @@ void ModuleWidget::initUI()
             m_pluginView->setModel(m_pluginModel);
 
             layout->addWidget(m_pluginView);
-            m_dconfigWatcher->bind("Control-Center_Dock_Plugins", m_pluginView);
+            m_dconfigWatcher->bind("dockPlugins", m_pluginView);
 
             for (auto name : plugins) {
                 DStandardItem *item = new DStandardItem(name);
