@@ -88,14 +88,12 @@ const QString SoundItem::contextMenu()
 
     QMap<QString, QVariant> open;
     open["itemId"] = MUTE;
-
-    // 如果没有可用输出设备，直接显示静音菜单不可用
-    if (!m_applet->existActiveOutputDevice()) {
+    if (m_sinkInter->mute()) {
         open["itemText"] = tr("Unmute");
-        open["isActive"] = false;
-    } else if (m_sinkInter->mute()) {
-        open["itemText"] = tr("Unmute");
-        open["isActive"] = true;
+        if (!m_applet->existActiveOutputDevice())
+            open["isActive"] = false;
+        else
+            open["isActive"] = true;
     } else {
         open["itemText"] = tr("Mute");
         open["isActive"] = true;
@@ -185,7 +183,7 @@ void SoundItem::refreshIcon()
 
     const double volmue = m_applet->volumeValue();
     const double maxVolmue = m_applet->maxVolumeValue();
-    const bool mute = m_applet->existActiveOutputDevice() ? m_sinkInter->mute() : true;
+    const bool mute = m_sinkInter->name().startsWith("auto_null") ? true : m_sinkInter->mute();
     const Dock::DisplayMode displayMode = Dock::DisplayMode::Efficient;
 
     QString iconString;
