@@ -394,7 +394,7 @@ void TrayPlugin::addTrayWidget(const QString &itemKey, AbstractTrayWidget *trayW
         return;
     }
 
-    if (m_trayMap.contains(itemKey) || m_trayMap.values().contains(trayWidget)) {
+    if (m_trayMap.values().contains(trayWidget)) {
         return;
     }
 
@@ -438,13 +438,17 @@ void TrayPlugin::traySNIAdded(const QString &itemKey, const QString &sniServiceP
             return;
         }
 
+        std::lock_guard<std::mutex> lock(m_sniMutex);
+        if (m_trayMap.contains(itemKey) || m_passiveSNITrayMap.contains(itemKey)) {
+            return;
+        }
+
         SNITrayWidget *trayWidget = new SNITrayWidget(sniServicePath);
 
         // TODO(lxz): 在future里已经对dbus进行过检查了，这里应该不需要再次检查。
         if (!trayWidget->isValid())
             return;
 
-        std::lock_guard<std::mutex> lock(m_sniMutex);
         if (trayWidget->status() == SNITrayWidget::ItemStatus::Passive) {
             m_passiveSNITrayMap.insert(itemKey, trayWidget);
         } else {
@@ -481,12 +485,22 @@ void TrayPlugin::traySNIAdded(const QString &itemKey, const QString &sniServiceP
             return false;
         }
 
+        // 1、确保服务有效
         QDBusInterface sniItemDBus(sniServerName, "/" + list.last());
         if (!sniItemDBus.isValid()) {
             qDebug() << "sni dbus service error : " << sniServerName;
             return false;
         }
 
+        // 部分服务虽然有效，但是在dbus总线上只能看到服务，其他信息都无法获取,这里通过Ping进行二次确认
+        // 参考: https://dbus.freedesktop.org/doc/dbus-specification.html#standard-interfaces
+
+        // 2、通过Ping接口确认服务是否正常
+        QDBusInterface peerInter(sniServerName, "/" + list.last(), "org.freedesktop.DBus.Peer");
+        QDBusReply<void> reply = peerInter.call("Ping");
+        if (!reply.isValid())
+            return false;
+
         return true;
     });
 
@@ -541,6 +555,7 @@ void TrayPlugin::trayRemoved(const QString &itemKey, const bool deleteObject)
         widget->setParent(nullptr);
     } else if (deleteObject) {
         widget->deleteLater();
+        widget = nullptr;
     }
 }
 
