@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2018 ~ 2028 Uniontech Technology Co., Ltd.
+ * Copyright (C) 2018 ~ 2020 Uniontech Technology Co., Ltd.
  *
  * Author:     chenjun <chenjun@uniontech.com>
  *
@@ -40,17 +40,15 @@ void Test_AppDrag::TearDown()
 {
 }
 
-TEST_F(Test_AppDrag, drag_test)
+TEST_F(Test_AppDrag, coverage_test)
 {
-    QWidget *w = new QWidget;
-    AppDrag *drag = new AppDrag(w);
+    QWidget w;
+    AppDrag drag(&w);
     QPixmap pix(":/res/all_settings_on.png");
-    drag->setPixmap(pix);
+    drag.setPixmap(pix);
 
-    ASSERT_TRUE(drag->appDragWidget());
+    ASSERT_TRUE(drag.appDragWidget());
 
-    drag->exec();
-
-    delete w;
-    w = nullptr;
+//    drag->exec();
+//    drag->exec(Qt::MoveAction, Qt::IgnoreAction);
 }
